summaryrefslogtreecommitdiff
path: root/addons/web/static/src
diff options
context:
space:
mode:
authorSEINLET Nicolas <nicolas@seinlet.com>2018-05-18 15:05:22 +0200
committerRaphael Collet <rco@odoo.com>2018-05-18 15:05:22 +0200
commit0b6182de383b98fc8b3da5ec58493f930b90b395 (patch)
tree8038674c988272764cbbfcb011ad205daaf7be87 /addons/web/static/src
parent3862c03ec27badef167acfc96c4f066ff14f0682 (diff)
[FIX] mail: speed up search on followers (#24737)
Odoo puts in cache all stored fields of a recordset when you access the first stored field not already in cache. In this particular case, Odoo will put in cache all stored fields of 'mail.followers', which is unnecessary and time consuming, especially on models where user follows plenty of records. With thousands of followed records, using a read() when searching on followers is around 2.5 times faster than using mapped(). Record rules based on followers are speed up the same way.
Diffstat (limited to 'addons/web/static/src')
0 files changed, 0 insertions, 0 deletions